Buckets Adapter
Buckets Adapter Django module is a base for upload files on bucket for different web services e.g Google Cloud Platform or Amazon Web Services which will be used as a package in different projects.